
import React, { useState } from 'react';
import { cn } from '@/lib/utils';
import { ChevronDown, ArrowRight, DollarSign, LineChart, TrendingUp, Download } from 'lucide-react';
import { Link } from 'react-router-dom';
import { Button } from '@/components/ui/button';
import { PDFDownloadButton as VCServicesPDFButton } from '@/components/PDFs/VCServicesPDF';
import { PDFDownloadButton as StartupProfilePDFButton } from '@/components/PDFs/StartupProfilePDF';

const FinanceSymbol = ({ symbol, className }: { symbol: string, className?: string }) => (
  <div className={cn(
    "absolute text-frugal-purple/30 font-display font-bold z-10",
    className
  )}>
    {symbol}
  </div>
);

const Hero: React.FC = () => {
  const [isImageLoaded, setIsImageLoaded] = useState(false);
  
  // Use smaller image for initial loading
  const heroImageSrc = "https://images.unsplash.com/photo-1460925895917-afdab827c52f?ixlib=rb-4.0.3&auto=format&fit=crop&w=1200&q=75";
  // Low-res placeholder
  const placeholderSrc = "https://images.unsplash.com/photo-1460925895917-afdab827c52f?ixlib=rb-4.0.3&auto=format&fit=crop&w=480&q=30";

  return (
    <section 
      className="relative min-h-[80vh] flex flex-col items-center justify-center px-6 overflow-hidden pb-10"
    >
      {/* Reduced number of finance symbols */}
      <FinanceSymbol symbol="$" className="top-[15%] left-[12%] text-5xl" />
      <FinanceSymbol symbol="%" className="bottom-[25%] left-[20%] text-4xl" />
      <FinanceSymbol symbol="€" className="top-[25%] right-[15%] text-4xl" />
      
      {/* Simplified background elements */}
      <div className="absolute top-0 left-0 w-full h-full -z-10">
        <div className="absolute top-0 left-0 w-full h-full bg-gradient-to-br from-white to-frugal-offwhite"></div>
        <div className="absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 w-[600px] h-[600px] bg-gradient-to-r from-frugal-mint/10 to-frugal-purple/10 rounded-full blur-[120px] -z-10"></div>
      </div>
      
      <div className="container max-w-5xl mx-auto pt-20 text-center z-10">
        <div className="inline-block px-4 py-1.5 mb-4 rounded-full bg-white/70 backdrop-blur-sm shadow-subtle border border-white/40">
          <span className="text-sm font-medium text-frugal-deep-purple flex items-center">
            <LineChart className="w-4 h-4 mr-2 text-frugal-purple" /> 
            Financial Strategy for Growth
          </span>
        </div>
        
        <h1 className="text-4xl md:text-5xl lg:text-6xl xl:text-7xl font-bold mb-4">
          <span className="bg-clip-text text-transparent bg-gradient-to-r from-frugal-purple to-frugal-mint">Smart finances</span> for ambitious companies
        </h1>
        
        <p className="max-w-2xl mx-auto text-lg md:text-xl text-gray-600 mb-6">
          Expert financial consulting that helps your business grow. 
          We bring clarity to your financial strategy.
        </p>
        
        <div className="flex flex-wrap justify-center gap-4 mb-8">
          <Link to="/contact">
            <Button size="lg" className="px-8 py-6 text-base bg-frugal-purple hover:bg-frugal-purple/90 text-white group">
              Book a Consultation
              <ArrowRight className="ml-2 h-4 w-4" />
            </Button>
          </Link>
          <Link to="#services">
            <Button 
              variant="outline" 
              size="lg" 
              className="px-8 py-6 text-base border-frugal-purple text-frugal-purple hover:bg-frugal-purple/10"
              onClick={(e) => {
                e.preventDefault();
                document.querySelector('#services')?.scrollIntoView({ behavior: 'smooth' });
              }}
            >
              Our Services
            </Button>
          </Link>
        </div>
        
        {/* Profile download buttons */}
        <div className="flex flex-wrap justify-center gap-4 mb-8">
          <div className="flex items-center justify-center gap-3 p-3 rounded-lg bg-white/70 backdrop-blur-sm border border-white/40">
            <Download className="w-5 h-5 text-frugal-purple" />
            <span className="text-frugal-deep-purple font-medium">Download Our Profiles:</span>
            <div className="flex gap-3">
              <StartupProfilePDFButton />
              <VCServicesPDFButton />
            </div>
          </div>
        </div>
        
        <div className="mt-8 relative">
          <div className="glass-panel rounded-2xl shadow-elevation-3 overflow-hidden border border-white/50 p-6 mx-auto max-w-3xl">
            <div className="absolute top-2 left-2 flex space-x-1.5">
              <div className="w-3 h-3 rounded-full bg-red-400"></div>
              <div className="w-3 h-3 rounded-full bg-yellow-400"></div>
              <div className="w-3 h-3 rounded-full bg-green-400"></div>
            </div>
            
            {/* Progressive image loading */}
            <div className="w-full h-full relative aspect-video">
              {/* Load only the high-res image without animation or placeholders */}
              <img 
                src={heroImageSrc}
                alt="Financial dashboard visualization" 
                className="w-full h-full object-cover rounded-lg"
                onLoad={() => setIsImageLoaded(true)}
                loading="eager" // Load eagerly as it's above the fold
              />
            </div>
          </div>
          
          {/* Static finance icons instead of animated ones */}
          <div className="absolute top-10 -left-4 bg-white rounded-full p-3 shadow-elevation-1">
            <DollarSign className="h-6 w-6 text-frugal-purple" />
          </div>
          <div className="absolute bottom-10 -right-4 bg-white rounded-full p-3 shadow-elevation-1">
            <TrendingUp className="h-6 w-6 text-frugal-mint" />
          </div>
        </div>
      </div>
      
      <div className="absolute bottom-4 left-0 right-0 flex justify-center">
        <a 
          href="#services" 
          className="text-gray-500 hover:text-frugal-purple transition-colors"
          onClick={(e) => {
            e.preventDefault();
            document.querySelector('#services')?.scrollIntoView({ behavior: 'smooth' });
          }}
        >
          <ChevronDown size={24} />
        </a>
      </div>
    </section>
  );
};

export default Hero;
